@@ -1,5 +1,5 @@
 /****************************************************************************
-*    Copyright © 2014-2024 The Tumultuous Unicorn Of Darkness
+*    Copyright © 2014-2025 The Tumultuous Unicorn Of Darkness
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
@@ -67,10 +67,14 @@ static inline bool check_data_path(const std::string file, const std::string ful
 /* Search file location in standard paths */
 static const std::string get_data_path(const std::string &file)
 {
+	std::string full_path;
+
+#if not defined (APPIMAGE) && not defined (FLATPAK)
 	/* Try to open file under CPU_X_DATA_DIRECTORY (CMake variable) */
-	std::string full_path = std::string(CPUX_DATA_DIRECTORY) + "/" + file;
+	full_path = std::string(CPUX_DATA_DIRECTORY) + "/" + file;
 	if(check_data_path(file, full_path))
 		return full_path;
+#endif
 
 	/* Fallback to system data directories */
 	for(const auto& dir : Glib::get_system_data_dirs())
